==> carbon-component-mapper-3.13.0.tgz: package/esm/time-picker-base/time-picker-base.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["WrapperProps", "input", "enhnancedOnBlur", "enhancedOnChange", "finalValue", "invalid", "twelveHoursFormat", "timezones", "helperText", "warnText", "selectFormat", "selectTimezone"],
    _excluded2 = ["showAs"];
import React from 'react';
import PropTypes from 'prop-types';
import CarbonTimePicker from "carbon-components-react/es/components/TimePicker/TimePicker.js";
import TimePickerSelect from "carbon-components-react/es/components/TimePickerSelect/TimePickerSelect.js";
import SelectItem from "carbon-components-react/es/components/SelectItem/SelectItem.js";
import HelperTextBlock from '../helper-text-block/helper-text-block';

var TimePickerBase = function TimePickerBase(_ref) {
  var WrapperProps = _ref.WrapperProps,
      input = _ref.input,
      enhnancedOnBlur = _ref.enhnancedOnBlur,
      enhancedOnChange = _ref.enhancedOnChange,
      finalValue = _ref.finalValue,
      invalid = _ref.invalid,
      twelveHoursFormat = _ref.twelveHoursFormat,
      timezones = _ref.timezones,
      helperText = _ref.helperText,
      warnText = _ref.warnText,
      selectFormat = _ref.selectFormat,
      selectTimezone = _ref.selectTimezone,
      rest = _objectWithoutProperties(_ref, _excluded);

  return /*#__PURE__*/React.createElement("div", WrapperProps, /*#__PURE__*/React.createElement(CarbonTimePicker, _extends({}, input, enhnancedOnBlur && {
    onBlur: enhnancedOnBlur
  }, enhancedOnChange && {
    onChange: function onChange(e) {
      return enhancedOnChange(e.target.value);
    }
  }, {
    onBlur: enhnancedOnBlur,
    value: finalValue,
    key: input.name,
    id: input.name,
    invalid: Boolean(invalid),
    invalidText: invalid || ''
  }, rest), twelveHoursFormat && /*#__PURE__*/React.createElement(TimePickerSelect, {
    labelText: "Period",
    id: "".concat(rest.id || input.name, "-12h"),
    onChange: function onChange(_ref2) {
      var value = _ref2.target.value;
      return selectFormat(value);
    }
  }, /*#__PURE__*/React.createElement(SelectItem, {
    value: "AM",
    text: "AM"
  }), /*#__PURE__*/React.createElement(SelectItem, {
    value: "PM",
    text: "PM"
  })), timezones && /*#__PURE__*/React.createElement(TimePickerSelect, {
    labelText: "Timezone",
    id: "".concat(rest.id || input.name, "-timezones"),
    onChange: function onChange(_ref3) {
      var value = _ref3.target.value;
      return selectTimezone(value);
    }
  }, timezones.map(function (_ref4) {
    var showAs = _ref4.showAs,
        tz = _objectWithoutProperties(_ref4, _excluded2);

    return /*#__PURE__*/React.createElement(SelectItem, _extends({
      key: tz.value,
      text: tz.label
    }, tz));
  }))), /*#__PURE__*/React.createElement(HelperTextBlock, {
    helperText: !invalid && helperText,
    warnText: warnText
  }));
};

TimePickerBase.propTypes = {
  isDisabled: PropTypes.bool,
  isReadOnly: PropTypes.bool,
  isRequired: PropTypes.bool,
  label: PropTypes.node,
  labelText: PropTypes.node,
  description: PropTypes.node,
  twelveHoursFormat: PropTypes.bool,
  timezones: PropTypes.arrayOf(PropTypes.shape({
    value: PropTypes.string.isRequired,
    label: PropTypes.node.isRequired,
    showAs: PropTypes.string
  })),
  WrapperProps: PropTypes.object,
  input: PropTypes.shape({
    name: PropTypes.string
  }).isRequired,
  enhnancedOnBlur: PropTypes.func,
  enhancedOnChange: PropTypes.func,
  finalValue: PropTypes.any,
  invalid: PropTypes.node,
  helperText: PropTypes.node,
  warnText: PropTypes.node,
  selectFormat: PropTypes.func.isRequired,
  selectTimezone: PropTypes.func.isRequired
};
export default TimePickerBase;

==> carbon-component-mapper-3.17.0.tgz: package/esm/time-picker-base/time-picker-base.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["WrapperProps", "input", "enhnancedOnBlur", "enhancedOnChange", "finalValue", "invalid", "twelveHoursFormat", "timezones", "helperText", "warnText", "selectFormat", "selectTimezone", "format", "timezone"],
    _excluded2 = ["showAs"];
import React from 'react';
import PropTypes from 'prop-types';
import CarbonTimePicker from "carbon-components-react/es/components/TimePicker/TimePicker.js";
import TimePickerSelect from "carbon-components-react/es/components/TimePickerSelect/TimePickerSelect.js";
import SelectItem from "carbon-components-react/es/components/SelectItem/SelectItem.js";
import HelperTextBlock from '../helper-text-block/helper-text-block';

var TimePickerBase = function TimePickerBase(_ref) {
  var WrapperProps = _ref.WrapperProps,
      input = _ref.input,
      enhnancedOnBlur = _ref.enhnancedOnBlur,
      enhancedOnChange = _ref.enhancedOnChange,
      finalValue = _ref.finalValue,
      invalid = _ref.invalid,
      twelveHoursFormat = _ref.twelveHoursFormat,
      timezones = _ref.timezones,
      helperText = _ref.helperText,
      warnText = _ref.warnText,
      selectFormat = _ref.selectFormat,
      selectTimezone = _ref.selectTimezone,
      format = _ref.format,
      timezone = _ref.timezone,
      rest = _objectWithoutProperties(_ref, _excluded);

  return /*#__PURE__*/React.createElement("div", WrapperProps, /*#__PURE__*/React.createElement(CarbonTimePicker, _extends({}, input, enhnancedOnBlur && {
    onBlur: enhnancedOnBlur
  }, enhancedOnChange && {
    onChange: function onChange(e) {
      return enhancedOnChange(e.target.value);
    }
  }, {
    onBlur: enhnancedOnBlur,
    value: finalValue,
    key: input.name,
    id: input.name,
    invalid: Boolean(invalid),
    invalidText: invalid || ''
  }, rest), twelveHoursFormat && /*#__PURE__*/React.createElement(TimePickerSelect, {
    defaultValue: format,
    labelText: "Period",
    id: "".concat(rest.id || input.name, "-12h"),
    onChange: function onChange(_ref2) {
      var value = _ref2.target.value;
      return selectFormat(value);
    }
  }, /*#__PURE__*/React.createElement(SelectItem, {
    value: "AM",
    text: "AM"
  }), /*#__PURE__*/React.createElement(SelectItem, {
    value: "PM",
    text: "PM"
  })), timezones && /*#__PURE__*/React.createElement(TimePickerSelect, {
    defaultValue: timezone,
    labelText: "Timezone",
    id: "".concat(rest.id || input.name, "-timezones"),
    onChange: function onChange(_ref3) {
      var value = _ref3.target.value;
      return selectTimezone(value);
    }
  }, timezones.map(function (_ref4) {
    var showAs = _ref4.showAs,
        tz = _objectWithoutProperties(_ref4, _excluded2);

    return /*#__PURE__*/React.createElement(SelectItem, _extends({
      key: tz.value,
      text: tz.label
    }, tz));
  }))), /*#__PURE__*/React.createElement(HelperTextBlock, {
    helperText: !invalid && helperText,
    warnText: warnText
  }));
};

TimePickerBase.propTypes = {
  isDisabled: PropTypes.bool,
  isReadOnly: PropTypes.bool,
  isRequired: PropTypes.bool,
  label: PropTypes.node,
  labelText: PropTypes.node,
  description: PropTypes.node,
  twelveHoursFormat: PropTypes.bool,
  timezones: PropTypes.arrayOf(PropTypes.shape({
    value: PropTypes.string.isRequired,
    label: PropTypes.node.isRequired,
    showAs: PropTypes.string
  })),
  WrapperProps: PropTypes.object,
  input: PropTypes.shape({
    name: PropTypes.string
  }).isRequired,
  enhnancedOnBlur: PropTypes.func,
  enhancedOnChange: PropTypes.func,
  finalValue: PropTypes.any,
  invalid: PropTypes.node,
  helperText: PropTypes.node,
  warnText: PropTypes.node,
  selectFormat: PropTypes.func.isRequired,
  selectTimezone: PropTypes.func.isRequired,
  format: PropTypes.oneOf(['AM', 'PM']),
  timezone: PropTypes.string
};
export default TimePickerBase;
